# -*- coding: utf-8 -*-
"""Installer for the eea.meeting package."""

import os
from setuptools import find_packages
from setuptools import setup


long_description = "\n\n".join(
    [
        open("README.rst").read(),
        open("CONTRIBUTORS.rst").read(),
        open("CHANGES.rst").read(),
    ]
)

NAME = "eea.meeting"
PATH = ["src"] + NAME.split(".") + ["version.txt"]
VERSION = open(os.path.join(*PATH)).read().strip()

setup(
    name=NAME,
    version=VERSION,
    description="Meeting support for Plone",
    long_description=long_description,
    # Get more from https://pypi.python.org/pypi?%3Aaction=list_classifiers
    classifiers=[
        "Environment :: Web Environment",
        "Framework :: Plone",
        "Framework :: Plone :: 4.3",
        "Programming Language :: Python",
        "Programming Language :: Python :: 2.7",
        "Operating System :: OS Independent",
        "License :: OSI Approved :: GNU General Public License v2 (GPLv2)",
    ],
    keywords="Python Plone",
    author="Valentin Dumitru",
    author_email="valentin.dumitru@eaudeweb.ro",
    url="https://pypi.python.org/pypi/eea.meeting",
    license="GPL version 2",
    packages=find_packages("src", exclude=["ez_setup"]),
    namespace_packages=["eea"],
    package_dir={"": "src"},
    include_package_data=True,
    zip_safe=False,
    install_requires=[
        "plone.api",
        "Products.GenericSetup>=1.8.2",
        "setuptools",
        "plone.app.dexterity",
        "plone.app.contenttypes",
        # 'plone.app.ldap',
        "plone.app.controlpanel",
        "plone.schema",
        "plone.behavior",
        "plone.app.z3cform",
        "plone.app.vocabularies",
        "plone.app.registry",
        "Products.MemcachedManager",
        "collective.geolocationbehavior",
        "plone.formwidget.geolocation<3",
        "collective.volto.formsupport",
    ],
    extras_require={
        "test": [
            "plone.app.testing",
            # Plone KGS does not use this version, because it would break
            # Remove if your package shall be part of coredev.
            # plone_coredev tests as of 2016-04-01.
            "plone.testing>=5.0.0",
            "plone.app.contenttypes",
            "plone.app.robotframework[debug]",
        ],
    },
    entry_points="""
    [z3c.autoinclude.plugin]
    target = plone
    """,
)
